@@ -24,8 +24,10 @@ import base64
 class Selenium(Scraper):
 
     def __init__(self, config: Config, headless: bool=True, window: dict={}, user_dir: str=None):
+        
+        url = config.get(section='SELENIUM', key='url')
 
-        if user_dir is None:
+        if user_dir is None or url is not None:
             options = webdriver.ChromeOptions()
         else:
             options = uc.ChromeOptions()
@@ -35,22 +37,21 @@ class Selenium(Scraper):
             # just some options passing in to skip annoying popups
             options.add_argument('--no-first-run --no-service-autorun --password-store=basic')            
 
-        #Remove navigator.webdriver Flag using JavaScript
-        options.add_argument('--disable-blink-features=AutomationControlled')
-
         #region options
         options.add_argument('--no-sandbox')
-        options.add_argument('--log-level=3')
-        options.add_argument('disable-infobars')
+        options.add_argument('--log-level=3')        
         options.add_argument('--disable-extensions')
         options.add_argument('--disable-dev-shm-usage')
-        options.add_argument("start-maximized")
-        options.add_argument("disable-infobars")
-        options.add_argument("--disable-extensions")
+
+        if user_dir is None:
+            options.add_argument("start-maximized")
+            options.add_argument("disable-infobars")
+            options.add_argument("--disable-extensions")
+            options.add_argument('disable-infobars')
 
         window_size = window['size'] if 'size' in window else []
 
-        if len(window_size) == 0:
+        if len(window_size) == 0 and user_dir is not None:
             options.add_argument('--start-maximized')
 
         if headless is True:
@@ -63,8 +64,6 @@ class Selenium(Scraper):
 
         #endregion options
 
-        url = config.get(section='SELENIUM', key='url')
-
         if user_dir is not None:
             self.driver = uc.Chrome(options=options)            
         elif url is not None:
